%define uname     vowpal_wabbit
%define major     0
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%define s2n_commit 270cf6efbc7efaae1ea017727079e929814b8002

%bcond_without  tests

Name:           vowpal-wabbit
Version:        9.10.0
Release:        %mkrel 2
Summary:        A fast and efficient machine learning system
License:        BSD
Group:          Sciences/Mathematics
Url:            https://hunch.net/~vw/
Source0:        https://github.com/JohnLangford/%{uname}/archive/%{version}/%{uname}-%{version}.tar.gz
Source1:        https://github.com/DLTcollab/sse2neon/archive/%{s2n_commit}/sse2neon.tar.gz
Patch0:         fix-build-error-with-fmt11.patch
Patch1:         vowpal_wabbit-9.10.0-soversion.patch
# Skip manpages generation.
Patch2:         vowpal_wabbit-9.10.0-skip-help2man.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  boost-devel
BuildRequires:  help2man
BuildRequires:  locales
BuildRequires:  rapidjson
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(spdlog)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(zlib)

%description
The Vowpal Wabbit (VW) project is a fast out-of-core learning system sponsored
by Microsoft Research and (previously) Yahoo! Research.

%package -n     %{libname}
Summary:        Main library for Vowpal Wabbit
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with vowpal-wabbit.

%package -n     %{develname}
Summary:        Headers for developing programs that will use Vowpal Wabbit
Group:          Development/C
Requires:       %{name} = %{version}
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the headers that programmers will need to develop
applications which will use Vowpal Wabbit.

%prep
%autosetup -p1 -a1 -n %{uname}-%{version}
mv -Tf sse2neon-%{s2n_commit} ext_libs/sse2neon/sse2neon

# fix python shebang
%py3_shebang_fix utl/vw-csv2bin

# drop -fvisibility=hidden
sed -i -e '/-fvisibility=hidden/d' CMakeLists.txt

%build
%cmake \
	-DVW_CXX_STANDARD=20 \
	-DWARNINGS:BOOL=OFF \
	-DUSE_LATEST_STD=ON \
	-DVW_INSTALL=ON \
	-DFMT_SYS_DEP=ON \
	-DRAPIDJSON_SYS_DEP=ON \
	-DSPDLOG_SYS_DEP=ON \
	-DVW_BOOST_MATH_SYS_DEP=ON \
	-DVW_ZLIB_SYS_DEP=ON \
	-DVW_EIGEN_SYS_DEP=ON \
	-DVW_BUILD_VW_C_WRAPPER=ON \
	-DVW_SSE2NEON_SYS_DEP=OFF \
	-DBUILD_TESTING=%{?with_tests:ON}%{!?with_tests:OFF} \
	-DBUILD_TESTING=ON \
	-DVW_GTEST_SYS_DEP=ON

%cmake_build

%install
%cmake_install

# install the utl scripts
install -m 0755 utl/logistic %{buildroot}%{_bindir}/
install -m 0755 utl/vw-convergence %{buildroot}%{_bindir}/
install -m 0755 utl/vw-csv2bin %{buildroot}%{_bindir}/
install -m 0755 utl/vw-hypersearch %{buildroot}%{_bindir}/
install -m 0755 utl/vw-regr %{buildroot}%{_bindir}/
install -m 0755 utl/vw-top-errors %{buildroot}%{_bindir}/
install -m 0755 utl/vw-varinfo %{buildroot}%{_bindir}/
install -m 0755 utl/vw2csv %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_datadir}/vowpalwabbit
install -m 0644 utl/vw-validate.html %{buildroot}%{_datadir}/vowpalwabbit/

# Check/generate manpages.
if [ ! -f %{buildroot}%{_mandir}/man1/vw.1 ]; then
mkdir -p %{buildroot}%{_mandir}/man1
help2man --no-info --name="Vowpal\ Wabbit\ --\ fast\ online\ learning\ tool" \
         %{buildroot}%{_bindir}/vw --output=%{buildroot}%{_mandir}/man1/vw.1
fi

%check
%{?with_tests: %ctest || : }

%files
%doc README.md AUTHORS
%license LICENSE
%{_bindir}/active_interactor
%{_bindir}/logistic
%{_bindir}/spanning_tree
%{_bindir}/vw
%{_bindir}/vw-convergence
%{_bindir}/vw-csv2bin
%{_bindir}/vw-hypersearch
%{_bindir}/vw-regr
%{_bindir}/vw-top-errors
%{_bindir}/vw-varinfo
%{_bindir}/vw2csv
%dir %{_datadir}/vowpalwabbit
%{_datadir}/vowpalwabbit/vw-validate.html
%{_mandir}/man1/vw.1*

%files -n %{libname}
%{_libdir}/libvw_c_wrapper.so.{%{version},%{major}}

%files -n %{develname}
%dir %{_includedir}/nonstd
%{_includedir}/nonstd/string_view.hpp
%dir %{_includedir}/vowpalwabbit
%{_includedir}/vowpalwabbit/*
%dir %{_includedir}/vw
%{_includedir}/vw/*
%{_libdir}/cmake/VowpalWabbit/
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/libvw_c_wrapper.pc


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 9.10.0-2.mga10
+ Revision: 2235893
- Mageia 10 Mass Rebuild
+ daviddavid <daviddavid>
- new version: 9.10.0 (thanks to Aurelian R)

* Mon Feb 10 2025 wally <wally> 8.8.0-19.mga10
+ Revision: 2146636
- rebuild for boost 1.87.0

* Fri Sep 13 2024 wally <wally> 8.8.0-18.mga10
+ Revision: 2095537
- rebuild for boost 1.86.0

* Wed Jun 19 2024 wally <wally> 8.8.0-17.mga10
+ Revision: 2075405
- rebuild for boost 1.85.0

* Sat Jan 13 2024 wally <wally> 8.8.0-16.mga10
+ Revision: 2030769
- rebuild for boost 1.84.0

* Wed Sep 27 2023 wally <wally> 8.8.0-15.mga10
+ Revision: 1991513
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 8.8.0-14.mga9
+ Revision: 1926541
- rebuild for boost 1.81.0

* Mon Aug 15 2022 neoclust <neoclust> 8.8.0-13.mga9
+ Revision: 1878057
- Rebuild against boost
+ wally <wally>
- rebuild for boost 1.79.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Wed Dec 22 2021 wally <wally> 8.8.0-10.mga9
+ Revision: 1763306
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 8.8.0-9.mga9
+ Revision: 1762611
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 8.8.0-8.mga9
+ Revision: 1744664
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 8.8.0-7.mga9
+ Revision: 1723031
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 8.8.0-6.mga8
+ Revision: 1666829
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 8.8.0-5.mga8
+ Revision: 1662071
- rebuild for boost 1.74.0

* Mon Aug 31 2020 martinw <martinw> 8.8.0-4.mga8
+ Revision: 1620538
- include man page

* Sun May 03 2020 wally <wally> 8.8.0-3.mga8
+ Revision: 1578125
- rebuild for boost 1.73.0

* Thu Feb 20 2020 umeabot <umeabot> 8.8.0-2.mga8
+ Revision: 1546417
- Mageia 8 Mass Rebuild

* Sun Feb 02 2020 wally <wally> 8.8.0-1.mga8
+ Revision: 1486444
- build without -fvisibility=hidden for now
- build with system rapidjson
- new version 8.8.0
- run vw-csv2bin python script through 2to3 and fix shebang
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Mon Dec 31 2018 daviddavid <daviddavid> 8.6.1-1.mga7
+ Revision: 1347643
- new version: 8.6.1

* Tue Oct 16 2018 wally <wally> 8.6.0-3.mga7
+ Revision: 1321114
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 8.6.0-2.mga7
+ Revision: 1301639
- Mageia 7 Mass Rebuild

* Tue Jul 10 2018 wally <wally> 8.6.0-1.mga7
+ Revision: 1242957
- new version 8.6.0
- drop unneeded linking patch
- define boost libdir for aarch64

* Mon Dec 25 2017 wally <wally> 8.2.1-6.mga7
+ Revision: 1184777
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 8.2.1-5.mga7
+ Revision: 1178356
- rebuild for boost 1.65

* Sun Sep 17 2017 tv <tv> 8.2.1-4.mga7
+ Revision: 1154959
- rebuild with latest boost

* Fri Sep 30 2016 wally <wally> 8.2.1-3.mga6
+ Revision: 1057904
- add patch to fix linking

* Mon Sep 26 2016 daviddavid <daviddavid> 8.2.1-2.mga6
+ Revision: 1057014
- disable build on ARMv5 as std::future does not exist

* Mon Sep 26 2016 daviddavid <daviddavid> 8.2.1-1.mga6
+ Revision: 1056759
- new version: 8.2.1
- update files list
- fix owner of data dir

* Sun Dec 27 2015 barjac <barjac> 7.3-10.mga6
+ Revision: 916058
- rebuild for boost-1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 7.3-9.mga6
+ Revision: 883810
- rebuild for new boost 1.59.0

* Tue Aug 25 2015 cjw <cjw> 7.3-8.mga6
+ Revision: 869265
- rebuild with gcc 5

* Fri Jul 31 2015 sander85 <sander85> 7.3-7.mga6
+ Revision: 860052
- Rebuild for new boost

* Wed Oct 15 2014 umeabot <umeabot> 7.3-6.mga5
+ Revision: 750937
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 7.3-5.mga5
+ Revision: 725278
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 7.3-4.mga5
+ Revision: 690239
- Mageia 5 Mass Rebuild

* Sat Feb 08 2014 barjac <barjac> 7.3-3.mga5
+ Revision: 586839
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 7.3-2.mga4
+ Revision: 533683
- Mageia 4 Mass Rebuild

* Tue Sep 03 2013 malo <malo> 7.3-1.mga4
+ Revision: 474822
- update to 7.3 and libification

* Wed Apr 10 2013 malo <malo> 7.2-2.mga4
+ Revision: 409436
- rebuild for boost 1.53

* Fri Apr 05 2013 malo <malo> 7.2-1.mga3
+ Revision: 408413
- update to 7.2, removed upstreamed patches

* Sat Jan 26 2013 malo <malo> 7.1-1.mga3
+ Revision: 392464
- fix build with upstream and linking patches
- patch for automake 1.13
- imported package vowpal-wabbit

